<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="备品库名称">
              <el-input maxlength="64" clearable placeholder="请输入备品库名称" v-model="querys[0].value"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="备品库编码">
              <el-input maxlength="32" clearable placeholder="请输入备品库编码" v-model="querys[1].value"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="append">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="upDateinfo"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column min-width="150" fixed prop="warehouseName" label="备品库名称"
          show-overflow-tooltip></el-table-column>
        <el-table-column fixed min-width="150" prop="warehouseCode" label="备品库编码"
          show-overflow-tooltip></el-table-column>
        <el-table-column min-width="150" prop="warehouseAddress" label="备品库地址" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="150" prop="longitude" label="经度" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="150" prop="latitude" label="纬度" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="150" prop="memo" label="备注" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <!-- 备品库弹窗 -->
    <SpareWarehouseModal @loadData="loadData" ref="WarehouseDia"></SpareWarehouseModal>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import SpareWarehouseModal from '@/views/Device/resourceManage/components/spareWarehouseDialog'
import SpareWarehouse from '@/api/device/SpareWarehouse.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
export default {
  name: 'SpareWarehouseManage',
  components: {
    SpareWarehouseModal,
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/device/base/warehouse/',
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'warehouseName',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'warehouseCode',
          relation: 'AND',
          value: '',
        },
      ],
      showWarehouseDia: false,
      pId: '',
    }
  },
  created() { },
  mounted() { },
  methods: {
    // 备品库
    append() {
      this.$refs.WarehouseDia.add()
    },
    // 备品库
    upDateinfo(data, type) {
      console.log(data)
      this.$refs.WarehouseDia.edit(data)
    },
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      SpareWarehouse.findSWList(this.queryParam, (res) => {
        console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
  },
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
